@@ -1,13 +1,13 @@
 package CGI::Session;
 
-# $Id: Session.pm 407 2008-04-08 00:56:47Z ron $
+# $Id: Session.pm 415 2008-06-16 14:40:45Z markstos $
 
 use strict;
 use Carp;
 use CGI::Session::ErrorHandler;
 
 @CGI::Session::ISA      = qw( CGI::Session::ErrorHandler );
-$CGI::Session::VERSION  = '4.30';
+$CGI::Session::VERSION  = '4.32';
 $CGI::Session::NAME     = 'CGISESSID';
 $CGI::Session::IP_MATCH = 0;
 
@@ -447,7 +447,7 @@ sub find {
     return 1;
 }
 
-# $Id: Session.pm 407 2008-04-08 00:56:47Z ron $
+# $Id: Session.pm 415 2008-06-16 14:40:45Z markstos $
 
 =pod
 
@@ -463,34 +463,38 @@ CGI::Session - persistent session data in CGI applications
 
     $CGISESSID = $session->id();
 
-    # send proper HTTP header with cookies:
+    # Send proper HTTP header with cookies:
     print $session->header();
 
-    # storing data in the session
+    # Storing data in the session:
     $session->param('f_name', 'Sherzod');
     # or
     $session->param(-name=>'l_name', -value=>'Ruzmetov');
 
-    # flush the data from memory to the storage driver at least before your
-    # program finishes since auto-flushing can be unreliable
+    # Flush the data from memory to the storage driver at least before your
+    # program finishes since auto-flushing can be unreliable.
+    # Warning: A bug in your logic whereby the DBI handle has gone
+    # out of scope before flush() is called means flush() won't work
+    # (when the session is a database session), so don't do that.
     $session->flush();
 
-    # retrieving data
+    # Retrieving data:
     my $f_name = $session->param('f_name');
     # or
     my $l_name = $session->param(-name=>'l_name');
 
-    # clearing a certain session parameter
+    # Clearing a certain session parameter:
     $session->clear(["l_name", "f_name"]);
 
-    # expire '_is_logged_in' flag after 10 idle minutes:
+    # Expire '_is_logged_in' flag after 10 idle minutes:
     $session->expire('is_logged_in', '+10m')
 
-    # expire the session itself after 1 idle hour
+    # Expire the session itself after 1 idle hour:
     $session->expire('+1h');
 
-    # delete the session for good
+    # Delete the session for good:
     $session->delete();
+    $session->flush(); # Recommended practice says use flush() after delete().
 
 =head1 DESCRIPTION
 
@@ -507,6 +511,20 @@ program exits.
 
 For instance, in a C<CGI::Application>-based program, C<sub teardown()> would be the appropriate place to do this.
 
+This is all part of what might be called "Object life-cycle 'v' Program life-cycle".
+
+In the simplest case the program has one object of type CGI::Session, and that object is destroyed when the
+program exits.
+
+If, however, you wish to delete objects explicitly, then each call to C<delete()> should be followed by a call
+to C<flush()>.
+
+Warning: A bug in your logic whereby the DBI handle has gone out
+out of scope before flush() is called means flush() won't work
+(when the session is a database session), so don't do that.
+
+For more detail, see the discussion of the C<delete()> method, below.
+
 =head1 A Warning about UTF8
 
 Trying to use UTF8 in a program which uses CGI::Session has lead to problems. See RT#21981 and RT#28516.
@@ -965,6 +983,10 @@ that worked with 3.x. For further details see:
 Consequently, always explicitly calling C<flush()> on the session before the program exits
 should be regarded as mandatory until this problem is rectified.
 
+Warning: A bug in your logic whereby the DBI handle has gone out
+out of scope before flush() is called means flush() won't work
+(when the session is a database session), so don't do that.
+
 =head2 atime()
 
 Read-only method. Returns the last access time of the session in seconds from epoch. This time is used internally while
@@ -1130,9 +1152,13 @@ Deletes a session from the data store and empties session data from memory, comp
 
 The intention is that in due course (of the program's execution) this will trigger L<flush()|/"flush">, and flush() will do the actual removal.
 
-However: Auto-flushing can be unreliable, and always explicitly calling C<flush()> on the session before the program exits
+However: Auto-flushing can be unreliable, and always explicitly calling C<flush()> on the session after C<delete()>
 should be regarded as mandatory until this problem is rectified.
 
+Warning: A bug in your logic whereby the DBI handle has gone out
+out of scope before flush() is called means flush() won't work
+(when the session is a database session), so don't do that.
+
 =head2 find( \&code )
 
 =head2 find( $dsn, \&code )
@@ -1409,6 +1435,7 @@ Bug reports can be submitted at http://rt.cpan.org/NoAuth/ReportBug.html?Queue=C
 Sherzod Ruzmetov E<lt>sherzodr@cpan.orgE<gt>, http://author.handalak.com/
 
 Mark Stosberg became a co-maintainer during the development of 4.0. C<markstos@cpan.org>.
+Ron Savage became a co-maintainer during the development of 4.30. C<rsavage@cpan.org>.
 
 =head1 SEE ALSO
 
