@@ -1,6 +1,6 @@
 package CGI::Session::Driver::DBI;
 
-# $Id: DBI.pm 394 2008-03-22 02:35:30Z markstos $
+# $Id: DBI.pm 415 2008-06-16 14:40:45Z markstos $
 
 use strict;
 
@@ -9,7 +9,7 @@ use Carp;
 use CGI::Session::Driver;
 
 @CGI::Session::Driver::DBI::ISA = ( "CGI::Session::Driver" );
-$CGI::Session::Driver::DBI::VERSION = '4.30';
+$CGI::Session::Driver::DBI::VERSION = '4.31';
 
 
 sub init {
@@ -123,7 +123,7 @@ sub remove {
     my ($sid) = @_;
     croak "remove(): usage error" unless $sid;
 
-   my $rc = $self->{Handle}->do( 'DELETE FROM '. $self->table_name .' WHERE id= ?',{},$sid );
+   my $rc = $self->{Handle}->do( 'DELETE FROM ' . $self->table_name . " WHERE $self->{IdColName}= ?", {}, $sid );
     unless ( $rc ) {
         croak "remove(): \$dbh->do failed!";
     }
@@ -135,7 +135,7 @@ sub remove {
 sub DESTROY {
     my $self = shift;
 
-    unless ( $self->{Handle} -> ping ) {
+    unless ( defined $self->{Handle} && $self->{Handle} -> ping ) {
         $self->set_error(__PACKAGE__ . '::DESTROY(). Database handle has gone away');
         return;
 	}
